# Django JSON:API Framework

Django JSON:API Framework makes it easier to build Django apps with REST API's
that follow the JSON:API specification.

## Resources

Django: https://www.djangoproject.com/
JSON:API: https://jsonapi.org/
